@@ -1,6 +1,5 @@
 use std::error::Error as StdError;
 use thiserror::Error;
-use url::ParseError;
 
 use crate::enums::RequestMethod;
 
@@ -17,14 +16,16 @@ pub enum ClientError {
     RequestError {
         source: Box<dyn StdError>,
         url: String,
-        method: RequestMethod,
+        method: String,
     },
     #[error("Error building HTTP request")]
     RequestBuildError {
-        source: Box<dyn StdError>,
+        source: http::Error,
         method: RequestMethod,
         url: String,
     },
+    #[error("Error building request for Reqwest crate")]
+    ReqwestBuildError { source: reqwest::Error },
     #[error("Error retrieving HTTP response")]
     ResponseError { source: Box<dyn StdError> },
     #[error("Error parsing server response as UTF-8")]
@@ -38,11 +39,11 @@ pub enum ClientError {
         content: Option<String>,
     },
     #[error("Server returned error")]
-    ServerResponseError {
-        url: String,
-        code: u16,
-        content: Option<String>,
-    },
+    ServerResponseError { code: u16, content: Option<String> },
+    #[error("Error building URL")]
+    UrlBuildError { source: http::uri::InvalidUri },
+    #[error("Error serializing URL query parameters")]
+    UrlQueryParseError { source: Box<dyn StdError> },
     #[error("Error parsing URL")]
-    UrlParseError { source: ParseError, url: String },
+    UrlParseError { source: url::ParseError },
 }
